{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "qiime2: Classify reads by taxon using a fitted classifier",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "qiime2/core:2018.4",
                    "id": "#qiime2-docker-hint.yml",
                    "name": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--i-classifier"
                    },
                    "label": "The taxonomic classifier for classifying the reads",
                    "type": "File",
                    "id": "#feature-classifier-classify-sklearn.cwl/classifier"
                },
                {
                    "inputBinding": {
                        "prefix": "--i-reads"
                    },
                    "label": "The feature data to be classified",
                    "type": "File",
                    "id": "#feature-classifier-classify-sklearn.cwl/rep_seqs"
                },
                {
                    "inputBinding": {
                        "prefix": "--o-classification"
                    },
                    "label": "Resulting taxonomy filename",
                    "type": "string",
                    "default": "taxonomy.qza",
                    "id": "#feature-classifier-classify-sklearn.cwl/taxonomy_filename"
                }
            ],
            "baseCommand": [
                "qiime",
                "feature-classifier",
                "classify-sklearn"
            ],
            "id": "#feature-classifier-classify-sklearn.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.taxonomy_filename)"
                    },
                    "id": "#feature-classifier-classify-sklearn.cwl/out_taxa"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Generate a tabular view of metadata",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "metadata file or artifact viewable as metadata",
                    "inputBinding": {
                        "prefix": "--m-input-file"
                    },
                    "id": "#metadata-tabulate.cwl/input_file"
                },
                {
                    "type": "string",
                    "label": "filename for the resulting visualization file",
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "id": "#metadata-tabulate.cwl/visualization_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.visualization_filename)"
                    },
                    "id": "#metadata-tabulate.cwl/visualization_artifact"
                }
            ],
            "baseCommand": [
                "qiime",
                "metadata",
                "tabulate"
            ],
            "id": "#metadata-tabulate.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "label": "qiime2 explore sample taxonomic composition",
            "doc": "Taxonomic analysis from https://docs.qiime2.org/2018.4/tutorials/moving-pictures/",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/classifier"
                },
                {
                    "type": "File",
                    "id": "#main/rep_seqs"
                },
                {
                    "type": "File",
                    "id": "#main/sample_metadata"
                },
                {
                    "type": "File",
                    "id": "#main/table"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/taxa_barplot/taxa_bar_plots",
                    "id": "#main/taxa_barplot_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/classify_features/out_taxa",
                    "id": "#main/taxonomy_artifact"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tabulate_metadata/visualization_artifact",
                    "id": "#main/taxonomy_visualization_file"
                }
            ],
            "steps": [
                {
                    "run": "#feature-classifier-classify-sklearn.cwl",
                    "in": [
                        {
                            "source": "#main/classifier",
                            "id": "#main/classify_features/classifier"
                        },
                        {
                            "source": "#main/rep_seqs",
                            "id": "#main/classify_features/rep_seqs"
                        },
                        {
                            "valueFrom": "taxonomy.qza",
                            "id": "#main/classify_features/taxonomy_filename"
                        }
                    ],
                    "out": [
                        "#main/classify_features/out_taxa"
                    ],
                    "id": "#main/classify_features"
                },
                {
                    "run": "#metadata-tabulate.cwl",
                    "in": [
                        {
                            "source": "#main/classify_features/out_taxa",
                            "id": "#main/tabulate_metadata/input_file"
                        },
                        {
                            "valueFrom": "taxonomy.qzv",
                            "id": "#main/tabulate_metadata/visualization_filename"
                        }
                    ],
                    "out": [
                        "#main/tabulate_metadata/visualization_artifact"
                    ],
                    "id": "#main/tabulate_metadata"
                },
                {
                    "run": "#taxa-barplot.cwl",
                    "in": [
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/taxa_barplot/sample_metadata"
                        },
                        {
                            "source": "#main/table",
                            "id": "#main/taxa_barplot/table"
                        },
                        {
                            "valueFrom": "taxa-bar-plots.qzv",
                            "id": "#main/taxa_barplot/taxa_bar_plots_filename"
                        },
                        {
                            "source": "#main/classify_features/out_taxa",
                            "id": "#main/taxa_barplot/taxonomy"
                        }
                    ],
                    "out": [
                        "#main/taxa_barplot/taxa_bar_plots"
                    ],
                    "id": "#main/taxa_barplot"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Produce an interactive barplot visualization of taxonomies",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Metadata file or artifact viewable as metadata",
                    "inputBinding": {
                        "prefix": "--m-metadata-file"
                    },
                    "id": "#taxa-barplot.cwl/sample_metadata"
                },
                {
                    "type": "File",
                    "label": "Feature table to visualize at various taxonomic levels",
                    "inputBinding": {
                        "prefix": "--i-table"
                    },
                    "id": "#taxa-barplot.cwl/table"
                },
                {
                    "type": "string",
                    "label": "The resulting visualization filename",
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "id": "#taxa-barplot.cwl/taxa_bar_plots_filename"
                },
                {
                    "type": "File",
                    "label": "Taxonomic annotations for features in the provided feature table",
                    "inputBinding": {
                        "prefix": "--i-taxonomy"
                    },
                    "id": "#taxa-barplot.cwl/taxonomy"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.taxa_bar_plots_filename)"
                    },
                    "id": "#taxa-barplot.cwl/taxa_bar_plots"
                }
            ],
            "baseCommand": [
                "qiime",
                "taxa",
                "barplot"
            ],
            "id": "#taxa-barplot.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
